==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_front/app/controllers/reminder_controller.rb <==
# -*- coding: utf-8 -*-

class ReminderController < PcController

  #
  # パスワード忘れた場合の再設定画面
  # params[:completion_url]がわたってきた場合は、リマインダー登録後その値の遷移先に遷移します。
  # params[:completion_url] = {:controller => 遷移させたいコントローラ名, :action => 遷移させたいアクション名 }
  #
  def index
    @reminder_form = flash[:reminder_form] || ReminderForm.new()
    @reminder_form.back_to_url ||= request.referer || '/'
    @reminder_form.set_completion_url(params[:completion_url])
    render :action => :index
  end

  #
  # パスワード変更完了
  #
  def reminder_completion
    return redirect_to(:action => 'index') unless request.post?
    reminder_form = ReminderForm.new(params[:reminder_form])
    # メールアドレスから秘密の質問を再度検索して反映(ajaxの例外が発生したときの場合のため)
    user = User.find(:first,
      :joins => "LEFT OUTER JOIN user_emails ON user_emails.user_id = users.id  AND (user_emails.deleted_at IS NULL OR user_emails.deleted_at > '#{Time.now.strftime('%Y-%m-%d %H:%M:%S')}')" ,
      :conditions => ["user_emails.email = ? and member_div = ?",  reminder_form.email, User.member_div_id_by_key(:membership)]
      )
    reminder_form.remember_question = user.remember_question unless user.nil?
    unless reminder_form.valid?
      flash[:reminder_form] = reminder_form
      redirect_to :action=> :index
      return
    end

    unless User.remind(reminder_form.email, reminder_form.remember_question, reminder_form.remember_answer, reminder_form.password, reminder_form.password_confirmation)
      reminder_form.errors.add(:remember_answer, i18n_message(:EM030002))
      flash[:reminder_form] = reminder_form
      redirect_to :action=> :index
    end

    self.current_user = User.authenticate(reminder_form.email, reminder_form.password)
    reset_session_with_keep_content # セッションを作り直しています。中身は一緒
    # :completion_urlがある場合はその値にリダイレクトします。
    if reminder_form.other_redirect?
      redirect_to :controller => reminder_form.completion_url_controller, :action => reminder_form.completion_url_action
    end
  end

  #
  # =　秘密の質問を取得　=
  #
  def get_remember_question
    user = User.find(:first,
      :joins => "LEFT OUTER JOIN user_emails ON user_emails.user_id = users.id  AND (user_emails.deleted_at IS NULL OR user_emails.deleted_at > '#{Time.now.strftime('%Y-%m-%d %H:%M:%S')}')" ,
      :conditions => ["user_emails.email = ? and member_div = ?",  params[:email], User.member_div_id_by_key(:membership)]
      )
    if user
      render :text => user.remember_question
    else
      render :text => ''
    end
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_front/app/controllers/reminder_controller.rb <==
# -*- coding: utf-8 -*-

class ReminderController < ApplicationController
  include EcRider::SetDefaultLayout
  include EcRider::PluginModule::Extendable

  #
  # パスワード忘れた場合の再設定画面
  # params[:completion_url]がわたってきた場合は、リマインダー登録後その値の遷移先に遷移します。
  # params[:completion_url] = {:controller => 遷移させたいコントローラ名, :action => 遷移させたいアクション名 }
  #
  def index
    @reminder_form = flash[:reminder_form] || ReminderForm.new()
    @reminder_form.back_to_url ||= params[:back_to_url] || '/'
    @reminder_form.set_completion_url(params[:completion_url])
    render :action => :index
  end

  #
  # パスワード変更完了
  #
  def reminder_completion
    return redirect_to(:action => 'index') unless request.post?
    reminder_form = ReminderForm.new(params[:reminder_form])
    # メールアドレスから秘密の質問を再度検索して反映(ajaxの例外が発生したときの場合のため)
    user = User.find(:first,
      :joins => "LEFT OUTER JOIN user_emails ON user_emails.user_id = users.id  AND (user_emails.deleted_at IS NULL OR user_emails.deleted_at > '#{Time.now.strftime('%Y-%m-%d %H:%M:%S')}')" ,
      :conditions => ["user_emails.email = ? and member_div = ?",  reminder_form.email, User.member_div_id_by_key(:membership)]
      )
    reminder_form.remember_question = user.remember_question unless user.nil?
    unless reminder_form.valid?
      flash[:reminder_form] = reminder_form
      redirect_to :action=> :index
      return
    end

    unless User.remind(reminder_form.email, reminder_form.remember_question, reminder_form.remember_answer, reminder_form.password, reminder_form.password_confirmation)
      reminder_form.errors.add(:remember_answer, i18n_message(:EM030002))
      flash[:reminder_form] = reminder_form
      redirect_to :action=> :index
    end

    current_user = User.authenticate(reminder_form.email, reminder_form.password)

    # メールアドレスが登録されていなければメールアドレス登録画面へ遷移する
    unless have_mailaddress?(current_user)
      session[:add_mailaddress] = {:target_user => current_user, :back_to_url => {:controller => reminder_form.completion_url_controller, :action => reminder_form.completion_url_action}}
      flash[:from_reminder] = true
      redirect_to :controller => :account, :action => :add_mailaddress
      return
    end

    self.current_user = current_user
    reset_session_with_keep_content # セッションを作り直しています。中身は一緒
    # :completion_urlがある場合はその値にリダイレクトします。
    if reminder_form.other_redirect?
      redirect_to :controller => reminder_form.completion_url_controller, :action => reminder_form.completion_url_action
    end
  end

  #
  # =　秘密の質問を取得　=
  #
  def get_remember_question
    user = User.find(:first,
      :joins => "LEFT OUTER JOIN user_emails ON user_emails.user_id = users.id  AND (user_emails.deleted_at IS NULL OR user_emails.deleted_at > '#{Time.now.strftime('%Y-%m-%d %H:%M:%S')}')" ,
      :conditions => ["user_emails.email = ? and member_div = ?",  params[:email], User.member_div_id_by_key(:membership)]
      )
    if user
      render :text => user.remember_question
    else
      render :text => ''
    end
  end

  #
  # ユーザがメールアドレスを持っているかどうか調べる
  # プラグインで拡張できるようにprivateメソッドに分けています
  #
  private
  def have_mailaddress?(current_user)
    return !!(current_user.user_email && current_user.user_email.email)
  end
end
